==> knowl_apidocs-0.2.7-py3-none-any.whl: knowl_apidocs/apidocs.py <==
import os
import sys
import platform
import subprocess
from .version import VERSION

def remove_quotes(s):
    return s.replace("\"", "").replace("\'", "").replace("\`", "")

def detect_os():
    current_os = platform.system()
    if current_os == "Linux":
        return "linux"
    elif current_os == "Darwin":
        return "mac"
    else:
        raise RuntimeError(f"This script is not supported on {current_os}. Please run it on Linux, or macOS.")

def get_url(os, version):
    url = f"https://s3.ap-south-1.amazonaws.com/releases.knowl.io/api-docs/apidocs_{os}_v{version}"
    binary_name = f"apidocs_{os}_v{version}"
    return url, binary_name

def run_subprocess(command, name="Operation"):
    try:
        binary_process = subprocess.Popen(command, universal_newlines=True,)
        binary_process.wait()
        if binary_process.returncode == 0:
            print(f"{name} completed successfully.")
        else:
            print(
                f"{name} failed with return code {binary_process.returncode}."
            )
            return 1
        return 0
    except subprocess.CalledProcessError as e:
        print(f"Error while running the script: {e}")
        return 1

MANDATORY_ENV_VARIABLE = ["OPENAI_API_KEY"]

def main():
    if len(sys.argv) < 2:
        raise RuntimeError("Path to Repo not provided")
    repo = sys.argv[1]
    repo_env_path = os.path.join(repo, ".knowlenv")
    if os.path.exists(repo_env_path):
        print("Loading variables from .knowlenv file.")
        with open(repo_env_path, "r") as file:
            lines = file.readlines()
        for line in lines:
            line = ''.join([char for char in line if not char.isspace()])
            line_split = line.split("=")
            env_key = line_split[0].strip()
            env_value = remove_quotes(line_split[1].strip())
            os.environ[env_key] = env_value        
    else:
        print(".env file not found.")

    for v in MANDATORY_ENV_VARIABLE:
        if v not in os.environ.keys():
            raise RuntimeError(f"{v} not found in ENVIRONMENT VARIABLES. Either add it to .knowlenv files or it add permanently as Environment variable")
    print("OPEN AI API KEY: ", os.environ["OPENAI_API_KEY"])
    current_os = detect_os()
    version = VERSION
    url, binary_name = get_url(current_os, version)
    path = os.path.join(os.getcwd(), binary_name)
    if os.path.exists(path):
        print("Binary file already exist.")
    else:
        command = ["wget", url]
        run_subprocess(command, "Downloading binary")
    command = ["chmod", "+x", path]
    run_subprocess(command, "Granting Executable Permission")
    command = [path, repo]
    run_subprocess(command, "Document Generation")

==> knowl_apidocs-0.2.8.1-py3-none-any.whl: knowl_apidocs/apidocs.py <==
import os
import sys
import platform
import subprocess
from .version import VERSION

def remove_quotes(s):
    return s.replace("\"", "").replace("\'", "").replace("\`", "")

def detect_os():
    current_os = platform.system()
    if current_os == "Linux":
        return "linux"
    elif current_os == "Darwin":
        return "mac"
    else:
        raise RuntimeError(f"This script is not supported on {current_os}. Please run it on Linux, or macOS.")

def get_url(os, version):
    url = f"https://s3.ap-south-1.amazonaws.com/releases.knowl.io/api-docs/apidocs_{os}_v{version}"
    binary_name = f"apidocs_{os}_v{version}"
    return url, binary_name

def run_subprocess(command, name="Operation"):
    try:
        binary_process = subprocess.Popen(command, universal_newlines=True,)
        binary_process.wait()
        if binary_process.returncode == 0:
            print(f"{name} completed successfully.")
        else:
            print(
                f"{name} failed with return code {binary_process.returncode}."
            )
            return 1
        return 0
    except subprocess.CalledProcessError as e:
        print(f"Error while running the script: {e}")
        return 1


def main():
    if len(sys.argv) < 2:
        raise RuntimeError("Path to Repo not provided")
    repo = sys.argv[1]
    package_path = os.path.dirname(os.path.abspath(__file__))
    current_os = detect_os()
    version = VERSION
    url, binary_name = get_url(current_os, version)
    binary_path = os.path.join(package_path, binary_name)
    if os.path.exists(binary_path):
        print("Binary file already exist.")
    else:
        command = ["wget", url, "-P", package_path]
        run_subprocess(command, "Downloading binary")
    command = ["chmod", "+x", binary_path]
    run_subprocess(command, "Granting Executable Permission")
    command = [binary_path, repo]
    run_subprocess(command, "Document Generation")

if __name__ ==  "__main__":
    main()
